#
# spec file for package fltk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libfltk1_3
Name:           fltk
Version:        1.3.9
Release:        2.5
Summary:        C++ GUI Toolkit for the X Window System, OpenGL, and WIN32
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://www.fltk.org/
Source0:        https://www.fltk.org/pub/fltk/%{version}/fltk-%{version}-source.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM fltk-1.3.4-fltk_config.patch tchvatal@suse.com -- obey libdir and other options in fltk-config taken from Fedora
Patch0:         fltk-1.3.4-fltk_config.patch
# PATCH-FIX-OPENSUSE fltk-1.3.2-verbose_build.patch reddwarf@opensuse.org -- Make the build verbose so the post build checks can verify the CFLAGS
Patch2:         fltk-1.3.2-verbose_build.patch
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)

%description
The Fast Light Tool Kit ("FLTK", pronounced "fulltick") is a C++
graphical user interface toolkit for the X Window System,
OpenGL, and Microsoft Windows NT 4.0, 95, or 98. The
installation of this package requires a 3D library such as Mesa.

%package devel
Summary:        Development files for the FLTK GUI toolkit
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(gl)
Requires:       pkgconfig(x11)
Provides:       fltk = %{version}

%description devel
The Fast Light Tool Kit ("FLTK", pronounced "fulltick") is a C++
graphical user interface toolkit for the X Window System,
OpenGL, and Microsoft Windows NT 4.0, 95, or 98. The
installation of this package requires a 3D library such as Mesa.

%package -n %{libname}
Summary:        The FLTK GUI toolkit library
Group:          System/Libraries
Obsoletes:      fltk < 1.3.2

%description -n %{libname}
The Fast Light Tool Kit ("FLTK", pronounced "fulltick") is a C++
graphical user interface toolkit for the X Window System,
OpenGL, and Microsoft Windows NT 4.0, 95, or 98. The
installation of this package requires a 3D library such as Mesa.

%package devel-static
Summary:        Static libraries for the FLTK GUI toolkit
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       fltk-devel = %{version}

%description devel-static
The Fast Light Tool Kit ("FLTK", pronounced "fulltick") is a C++
graphical user interface toolkit for the X Window System,
OpenGL, and Microsoft Windows NT 4.0, 95, or 98. The
installation of this package requires a 3D library such as Mesa.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 2

%build
%configure \
  --with-optim="%{_lto_cflags} -ffat-lto-objects" \
  --enable-shared \
  --disable-localjpeg \
  --disable-localzlib \
  --disable-localpng \
  --enable-threads

%make_build
cd documentation
%make_build html

%install
make install libdir=%{buildroot}%{_libdir}/ \
	     includedir=%{buildroot}%{_includedir} \
	     bindir=%{buildroot}%{_bindir} \
	     docdir=%{buildroot}/%{_docdir}/fltk-devel/html/ \
	     mandir=%{buildroot}%{_mandir} STRIP=true
rm -r %{buildroot}%{_mandir}/cat*

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files devel
%doc examples makeinclude
%doc %{_docdir}/fltk-devel
%{_mandir}/man*/*
%{_libdir}/*.so
%{_includedir}/*
%{_bindir}/*

%files -n %{libname}
%license COPYING
%doc CHANGES README
%{_libdir}/*.so.*

%files devel-static
%{_libdir}/libfltk*.a

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Dec 30 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.9:
  * Support macOS up to macOS 14 "Sonoma".
  * Update bundled libraries to current versions (see below).
  * Introduce bundled image library "prefixing" to avoid
    conflicts with system libraries.
  * Bundled library versions (see also README.bundled-libs.txt):
  * Library       Version            Release date
  * jpeg          jpeg-9e            2022-01-16
  * png           libpng-1.6.40      2023-06-21
  * zlib          zlib-1.3           2023-08-18
  * Backport X11 INCR protocol fixes from 1.4.0 (issue #451)
  * X11: Suppress compiler warnings when using gcc or clang
  * Fix crash if a program exits before it opens a window
  * Fix compilation error with current Visual Studio 2022
  * Backport warning fixes from 1.4.0 in src/fl_draw.cxx
  * Fix compiler warning as pointed out in PR #693
  * Fix another compiler warning (#693)
  * Remove unused variable, fix "type issue" (#445, part 2)
  * Fix stack buffer overflow found by address sanitizer
  * Fix "gtk+ rendering" (GitHub Issue #443)
  * Fix doxygen warnings
  * Bump version numbers, prepare release 1.3.9
  * Fix several compiler warnings
  * Update bundled image libraries and zlib to current
    versions
  * Update README, README.CMake.txt, and some support files
  * Fix compiler warnings: backported from 1.4 (git 'master')
  * CMake/MSVC: remove confusing recommendation to rerun
  * Documentation: remove dark color on title page
  * Raise CMake minimum required version to 3.15 and more
  * macOS platform: Issue #325 "Disabling IM disables Greek
    and Cyrillic layouts"
  * Fix fullscreen window level corner cases on macOS
  * Fix issue #373 apparent with macOS platform and SDK ≤
  * Issue #452: Fl::get_font_name failure on OS-X.
  * Issue #454: crash in Fl::get_font_name().
  * Issue #469: Fl_Sys_Menu_Bar menu item shortcuts using Esc
    Tab don't work on Mac
  * Fix "Focus is lost leaving full screen on macOS 13"
  * Add support of macOS Ventura 13.0 and macOS Sonoma 14.0
  * macOS: remove configure option --enable-x11 and CMake
    OPTION_APPLE_X11; this functionality remains in FLTK 1.4.
  * configure.ac: make sure local-png and local-zlib always
    run together
  * Remove the -mwindows argument from CFLAGS and CXXFLAGS
* Mon Jan 10 2022 Dirk Müller <dmueller@suse.com>
- drop explicit pie flags setting and use --with-optim to
  pass in optimizer flags (bsc#1194419), binary is pie now
  automatically
- disable building against local copies of libjpeg etc
* Sat Jan  8 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix LDFLAGS reported by fltk-config (strip -pie), which breaks
  building shared libraries linking to libfltk (boo#1194419)
* Fri Dec  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.8:
  * Add new dialog with extended return values
  * Make "FLTK_CONSOLIDATE_MOTION" user-definable
- Use bzip2 compressed sources
* Sat Nov 13 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3.7:
  * see CHANGES
  * maintenance release with new macOS Big Sur support
    and some bug fixes. macOS Big Sur is supported on both Intel and the
    new Apple Silicon (M1) chips.
* Wed Oct 20 2021 pgajdos@suse.com
- fix shlib-policy-name-error [bsc#1191754]
- modified sources
  %% baselibs.conf
* Thu Apr 22 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- explicitly pass -fPIC and -pie via CFLAGS and LDFLAGS to make /usr/bin/fluid
  an position-independent executable. fltk by default passed -fPIC but not
  - pie, which breaks our gcc-PIE profil. (bsc#1184122).
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 1.3.5
  * see CHANGES or
    https://www.fltk.org/articles.php?L1635
* Fri Aug  9 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Mon Jan 29 2018 pgajdos@suse.com
- added xcursor dependency [bsc#1077881]
* Tue Jul 25 2017 jengelh@inai.de
- Trim description, drop TM/R marks according to guidelines.
* Mon Jul 17 2017 tchvatal@suse.com
- Drop patch fltk-1.3.2-do_not_add_unneeded_extra_dependencies.patch
  as upstream closed the ticked stating it is wrong
- Add patch fltk-1.3.4-fltk_config.patch
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly package %%{_docdir}/fltk-devel in order to fix build
  with RPM 4.13.0.
* Mon Nov 21 2016 pgajdos@suse.com
- updated to 1.3.4: see CHANGES
- remove fltk-1.3.3-do-not-use-internal-ABI.patch (upstreamed)
* Mon Jan 26 2015 dimstar@opensuse.org
- Add fltk-1.3.3-do-not-use-internal-ABI.patch: do not use internal
  function Fl_XFont_On_Demand::value(), which changes ABI based on
  the configuration. Add a fl_core_font() getter for the same.
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.3.3
  +Very much changes; please have a look on CHANGES file
- Remove fltk-1.3.2-underlinking.patch; merged upstream
* Sat Oct 25 2014 crrodriguez@opensuse.org
- Correct -devel package dependencies
  * /usr/include/FL/x*.H needs x11 headers
  * /usr/include/FL/gl*.H needs gl headers.
* Tue Mar  5 2013 jw@suse.com
- added a fltk-devel-static subpackage to transport libfltk*.a
  as needed by Documentation:Tools/flpsed.
* Fri Jan 25 2013 pgajdos@suse.com
- by previous change, files of fltk maint package was moved to
  fltk-devel, keeping fltk empty; thus:
  * libfltk1 obsoletes fltk
  * fltk-devel provides fltk
* Thu Jan 10 2013 reddwarf@opensuse.org
- updated to 1.3.2:
  - Removed unnecessary drawing calls (STR #2898)
  - Fixed regression in FLTK 1.3.1 for unbundled Mac OS FLTK applications that
    did not appear in dock nor have a menu bar (STR #2890).
  - Fl_Table::clear() now calls table->clear() for consistency. (STR #2889)
  - Fixed Fl_Scroll widget that fails under Mac OS X 10.8 and retina display (STR #2887).
  - Prevents scrollbars from drawing when widget is sized too small to be visible (STR #2886).
  - Documented how to make a Mac OS X FLTK application launchable by dropping files on its icon.
  - Fixed a Mac-specific issue appeared with OS 10.8 (Mountain Lion): long delay before
    opening when the application is started by dragging a file on the application icon.
  - Fixed use of PNG image from im-memory data (STR #2884).
  - Added static Fl_RGB_Image::max_size(size_t) to limit the maximum memory size allowed to
    RGB images (STR #2881).
- add fltk-1.3.2-do_not_add_unneeded_extra_dependencies.patch to avoid adding unneeded libraries
  to the link command of dependent packages. Those libraries didn't even need to be installed.
- remove automake BuildRequire
- substitute %%if crazyness for pkgconfig() style BuildRequires
- correct libfltk1 group
- get rid of the fltk package which only contained duplicated doc files, probably by a packaging accident
- add fltk-1.3.2-verbose_build.patch
- add fltk-1.3.2-underlinking-patch
- remove fltk-as-needed.patch (integrated into fltk-1.3.2-underlinking-patch)
- don't add -fno-strict-aliasing to CFLAGS. Upstream already does that
- don't set glflags and fltkflags for make. I don't see it doing anything useful
* Tue Nov 20 2012 pgajdos@suse.com
- updated to 1.3.1:
  - Fixed utf_strncasecmp and utf_strcasecmp
  - Moved all inline constructors into source file to avoid bad DLLs
  - Fixed Fl_Widget::copy_label() and Fl_Window::copy_label() when
    called with the old label() (STR #2836)
  - Fixed Fl_Input_::maximum_size() documentation and replace() method
    to honor maximum_size() as number of allowed characters (STR #2747).
  - Fixed a potential crash if Fl_Double_Window::flush() was called
    before show()
  - Fixed regression (in FLTK 1.3.0) that could clear a radio
    button by using the keyboard (space or shortcut) (STR #2748)
  - Fixed fl_pie() drawing too small on X11 (STR #2703)
  - Fixed Fl_Menu issue with unusual menu flags (STR #2680)
  - Fixed Windows DLL import of fl_xid() (STR #2670)
  - Added Fl::screen_work_area() functions that compute the work area
    of a screen. These functions improve the positioning of menus.
    Changed Fl::x(), Fl::y(), Fl::w(), Fl::h() functions
    to return the origin and size of the work area of the main screen
    (STR #2695 + 2697)
  - Created the FL_SCREEN_CONFIGURATION_CHANGED event that is triggered
    when a screen is added, removed, moved or when resolution is changed
    (STR #2600)
  - Improved the description of page size and orientation by
    Fl_PostScript_File_Device.
  - Added support for horizontal wheel movement under X11 and MSWindows Vista
    and above (STR #2644).
    1.3.1 ABI FEATURES
    (To enable the following ABI features, put: #define FLTK_ABI_VERSION 10301
    at the top of your FL/Enumerations.H and rebuild FLTK and your app)
  - Fl_Tree optimized to support large trees (eg. 100k items):
    Added _next_sibling and _prev_sibling to Fl_Tree_Item class,
    and support methods.
* Thu Jul 26 2012 coolo@suse.com
- buildrequires on specific library sonames is breaking build
* Mon Feb 20 2012 coolo@suse.com
- let the devel package buildrequire xorg-x11-devel
* Thu Dec 22 2011 pgajdos@suse.com
- buildrequires automake
* Wed Dec 21 2011 pgajdos@suse.com
- fixed linking library with as-needed [bnc#736410]
  * as-needed.patch
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
- Implement baselibs config
* Mon Jul 11 2011 pgajdos@novell.com
- updated to 1.3.0:
  * Added UTF-8 Unicode support throughout FLTK and Fluid
  * Added Fl_Tree widget for hierarchical views
  * Added Fl_Table widget for widget layout
  * Added Fl_Native_Filechooser as a widget and global options
  * etc., see CHANGES
  * removed upstreamed and unneeded patches
* Thu Aug 26 2010 pgajdos@suse.cz
- update to 1.1.10
  changes since rc3
  - Widgets now remove stale entries from the default callback
    queue when they are deleted (STR #2302)
  - Fixed selection bug in Fl_Int_Input (STR #2292)
  for all changes see the /usr/share/doc/packages/fltk/CHANGES
* Wed Mar 31 2010 john@redux.org.uk
- Added support for building on Fedora, RHEL 5/CentOS 5 and
  Mandriva.
- Added patch for use of printf-style varags functions.
- "cast" patch disabled for many build targets, as it caused the
  builds to fail.
* Fri Dec 18 2009 jengelh@medozas.de
- enable parallel building
* Tue Dec  1 2009 pgajdos@suse.cz
- update to version 1.1.10rc3
- splitted out libfltk1
- some specfile cleanups
* Tue Aug  4 2009 pgajdos@suse.cz
- fixed link_gl.patch to build package
* Sat Jun 20 2009 cmorve69@yahoo.es
- add missing DT_NEEDEDs, fixes alsa-tools build with --as-needed
* Mon Jun  8 2009 pgajdos@suse.cz
- fixed build with new g++
* Tue Jul  1 2008 pgajdos@suse.cz
- updated to 1.1.9:
  * Improved color contrast in secondary selection blocks
    of Fl_Text_Display
  * Fixed regression in callback handling
  * Fixed wrong relative path when absolute path has a
    trailing slash in fl_filename_relative
  * Fixed multiple selction of files and directories in
    Fl_File_Chooser
* Mon Apr  7 2008 pgajdos@suse.cz
- updated to 1.1.8:
  * many buxfixes
  * added documentation about the potential limitations
    of Fl::grab on newer operating systems (STR #1747)
  * FLUID checks for seperately declared callbacks to
    avoid a bogus "extern" declaration (STR #1776)
  * Added "protected" class memebrs in FLUID
  * Double-clicking a widget in a FLUID layout will show
    the item in the widget browser
  * gl_font() support for Xft+X11 (STR #1809)
  * Fl_Gl_Window::mode() needed to hide and show the window
    when toggling stereo mode (STR #1846)
  * Added Fl_Group::clip_children() methods to support
    automatic clipping of child widget drawing (STR #1844)
  * Fl_Browser_ and friends now support FL_WHEN_ENTER_KEY
    for both Enter/Return and double-clicks (STR #1818)
  * Fl_Help_View did not release the images it used (STR
    [#1817])
  * Shared libraries would not build on 64-bit Linux
    systems with an existing non-PIC FLTK installation
    (STR #1791)
- removed test dir with similar contents as examples dir
* Thu Aug 30 2007 uli@suse.de
- enable threads
* Mon Apr 16 2007 pgajdos@suse.cz
- update files from CVS in CinePaint project
  * casting between (void*) and int cleanups
  * see http://cinepaint.bigasterisk.com/FLTK
* Thu Oct  5 2006 lmichnovic@suse.cz
- fixed casting on 64bit arch (intptr_t.patch)
- compiling with no-strict-aliasing
- fixed wrongly called ranlib with fixed libdir in variable
  (libdir.patch)
* Mon Aug  7 2006 lmichnovic@suse.cz
- fixed prefixes accordingly to new X.org 7.x, detecting prefix in X.org
* Fri Aug  4 2006 postadal@suse.cz
- updated to version 1.1.7
  * added some new example programs
  * adds many new improvements to the FLUID software (multi-level undo,
    syntax highlighting in all code fields, widget alignment and sizing
    guides, dialog templates, widget subclasses, and printing and testing
    of user interfaces)
  * fixed many bugs
- removed obsoleted patches: gcc3.1-fix.dif, cast-fix.diff
* Mon Feb 13 2006 pnemec@suse.cz
- Fixed class cast errors in testsuite.
* Mon Feb  6 2006 aj@suse.de
- Reduce BuildRequires.
- Fix some testsuite errors.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 12 2005 postadal@suse.cz
- updated to version 1.1.6
- removed obsoleted patches: fltk-1.1.6-fix.dif and fltk-1.1.6-gcc34hack.patch
* Thu Jan 15 2004 meissner@suse.de
- Upgraded to 1.1.4.
- Added a hack so it compiles with gcc 3.4pre, remove when GCC
  bug 13696 is fixed.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directories to filelist
* Fri Feb 14 2003 postadal@suse.cz
- updated to version 1.1.3
  * documentation update
  * fixes
* Thu Jan  9 2003 postadal@suse.cz
- updated to version 1.1.2 (a lot of fixes)
- fixed undefined references to non-weak symbols
* Wed Jan  8 2003 ro@suse.de
- fix configure.in
* Wed Nov 20 2002 meissner@suse.de
- Upgraded to 1.1.1, upgraded fltk-delete-fix.dif, fixed neededforbuild.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Sep  4 2002 postadal@suse.cz
- added %%run_ldconfig macro [#18897]
* Tue Aug 13 2002 uli@suse.de
- fixed installation on lib64 archs
* Mon Aug 12 2002 postadal@suse.cz
- update to version 1.1.0rc5
  * a lot of fixes
* Sun May  5 2002 schwab@suse.de
- Fix invalid delete.
- Use $RPM_OPT_FLAGS.
* Fri Apr 19 2002 postadal@suse.cz
- used macro %%{_lib} and fixed Makefile
- updated to 1.1.0b13
  * Documentation updates
  * Stereo OpenGL support
  * Added support for Xft lib to provide anti-aliased text on X11
  * Initial port of FLTK 2.0 drag-and-drop support
* Wed Apr 10 2002 tiwai@suse.de
- fixed workaround for gcc 3.1 in configure script.
* Mon Feb  4 2002 nadvornik@suse.cz
- updated to 1.1.0b10
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 14 2002 schwab@suse.de
- Remove ia64 workaround.
* Mon Jan 14 2002 nadvornik@suse.cz
- added fltk-config to filelist
* Tue Dec 11 2001 nadvornik@suse.cz
- updated to 1.1.0b6
- added libjpeg and libpng to neededforbuild
* Thu Nov  8 2001 tiwai@suse.de
- updated to 1.1.0b5.
  built now on gcc-3.0 / beta environment, too.
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Thu Sep 27 2001 dan@suse.cz
- update to 1.1.0b1 that includes:
  * added new widgets
  * support for mouse wheels
  * keyboard navigation to all widgets
* Mon Aug 27 2001 kukuk@suse.de
- split off devel subpackage
* Fri May 25 2001 pblaha@suse.cz
- update on 1.0.11
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Thu Mar  8 2001 pblaha@suse.cz
- update on 1.0.10
* Wed Mar  7 2001 ro@suse.de
- added glu and glut packages
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Mon Jul 10 2000 mha@suse.de
- new version: 1.0.9
* Tue Jun 20 2000 schwab@suse.de
- Lower opt level on ia64.
* Wed May 24 2000 smid@suse.cz
- fix to compile with new mesa
* Fri Apr 21 2000 smid@suse.cz
- buildroot added
* Mon Feb 14 2000 mha@suse.de
- update to 1.0.7
* Wed Sep 29 1999 mha@suse.de
- update to 1.0.6
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 20 1999 mha@suse.de
- removed call to "glXReleaseBuffersMESA", which only exists
  in mesasoft, but not in any hardware-accelerated OpenGL library
* Mon Jul 19 1999 bs@suse.de
- added Check
* Mon Jul 19 1999 mha@suse.de
- new package: FLTK (pronounced "fulltick") is a LGPL'd C++ graphical
  user interface toolkit for X (UNIX®), OpenGL, and WIN32 (Microsoft®
  Windows® NT 4.0, 95, or 98)
